summaryrefslogtreecommitdiffstats
path: root/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake_hybi.py
diff options
context:
space:
mode:
Diffstat (limited to 'testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake_hybi.py')
-rwxr-xr-xtesting/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake_hybi.py16
1 files changed, 9 insertions, 7 deletions
diff --git a/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake_hybi.py b/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake_hybi.py
index 8c65822170..ee63ed45b4 100755
--- a/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake_hybi.py
+++ b/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_handshake_hybi.py
@@ -31,15 +31,17 @@
"""Tests for handshake module."""
from __future__ import absolute_import
-import unittest
-import set_sys_path # Update sys.path to locate mod_pywebsocket module.
-from mod_pywebsocket import common
-from mod_pywebsocket.handshake.base import AbortedByUserException
-from mod_pywebsocket.handshake.base import HandshakeException
-from mod_pywebsocket.handshake.base import VersionException
-from mod_pywebsocket.handshake.hybi import Handshaker
+import unittest
+import set_sys_path # Update sys.path to locate pywebsocket3 module.
+from pywebsocket3 import common
+from pywebsocket3.handshake.base import (
+ AbortedByUserException,
+ HandshakeException,
+ VersionException,
+)
+from pywebsocket3.handshake.hybi import Handshaker
from test import mock